@@ -6,7 +6,6 @@
 #include "string.h"
 #include "../../cem/cem.h"
 
-static void end_avatar_view();
 
 typedef enum{BLACK, BLOND, BLUE, BROWN, DARKBROWN, GRAY, ORANGE, VIOLET, WHITE}HAIR_COLOR;
 typedef enum{BROWN_HEAD, DARK_HEAD, PINK_HEAD, YELLOW_HEAD}HEADS;
@@ -26,6 +25,11 @@ static TextField nameTextField;
 static TextField genderTextField;
 
 static void change_hair_type() ;
+static void end_avatar_view();
+
+/*
+* Starts avatar editor.
+*/
 void start_avatar_editor(){
 
 	//Creating default user to test avatar saving!
@@ -36,12 +40,32 @@ void start_avatar_editor(){
 		gems_profile_manager_create_default_user_profile("sala", 23);// For testing only!!!
 		gems_profile_manager_authenticate_default_user("sala");// For testing only!!!
 		start = 0;// // For testing only!!!
-		}
-		
-		
+	}
+	//TODO: Get real userid
 
+	gboolean profileFound = FALSE;
 	guint32 avatar_id = 0;
-
+	gchar* profile_path = g_strdup_printf("%s/user_%d.csv", configure_get_jammo_directory(), /*avatar_id*/TEST_USERID);
+	char line[200];
+	int id = 0;
+	gchar* name = "";
+	gchar* hobbies = "";
+	gchar* gender = "";
+	
+	FILE *f;
+	if ((f = fopen(profile_path, "r")) == NULL){
+		profileFound = FALSE;
+		printf("Error happened while trying to read profile file.\n");	
+	}else{
+		profileFound = TRUE;
+		while(fgets(line, sizeof(line), f)){
+			id = atoi(strtok(line, ", "));  
+    	  	name = strtok(NULL, ", ");  
+	       	hobbies = strtok(NULL, ", "); 
+	       	gender = strtok(NULL, ", ");	
+		}
+	}
+	g_free(profile_path);
 	cem_add_to_log("Starting avatar editor", J_LOG_DEBUG);
 
 	ClutterActor* mainview;
@@ -62,31 +86,35 @@ void start_avatar_editor(){
 		clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("avatar_gender_text")), _("GENDER:"));
 		clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("avatar_instrument_text")), _("FAVOURITE INSTRUMENT:"));
 		
-		
-		
 		hobbiesTextField.text = jammo_get_actor_by_id("avatar_hobbies_textfield");
-		clutter_text_set_text(CLUTTER_TEXT(hobbiesTextField.text), _("<<YOUR HOBBIES HERE>>"));
 		hobbiesTextField.lineCount = 2;
 		hobbiesTextField.max_characters = 500;
-		hobbiesTextField.handler_id = g_signal_connect_swapped(hobbiesTextField.text, "text-changed", (GCallback)limit_line_count, &hobbiesTextField);
- 
 		
-		nameTextField.text = jammo_get_actor_by_id("avatar_name_textfield");
-		clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _("<<YOUR NAME HERE>>"));
+		nameTextField.text = jammo_get_actor_by_id("avatar_name_textfield");	
 		nameTextField.lineCount = 1;
 		nameTextField.max_characters = 500;
-		nameTextField.handler_id = g_signal_connect_swapped(nameTextField.text, "text-changed", (GCallback)limit_line_count, &nameTextField);		
 		
-		genderTextField.text = jammo_get_actor_by_id("avatar_gender_textfield");
-		clutter_text_set_text(CLUTTER_TEXT(genderTextField.text), _("<<YOUR GENDER HERE>>"));
+		genderTextField.text = jammo_get_actor_by_id("avatar_gender_textfield");	
 		genderTextField.lineCount = 1;
 		genderTextField.max_characters = 500;
+		
+		if(profileFound){
+			clutter_text_set_text(CLUTTER_TEXT(hobbiesTextField.text), _(hobbies));
+			clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _(name));
+			clutter_text_set_text(CLUTTER_TEXT(genderTextField.text), _(gender));
+		}else{
+			clutter_text_set_text(CLUTTER_TEXT(hobbiesTextField.text), _("<<YOUR HOBBIES HERE>>"));
+			clutter_text_set_text(CLUTTER_TEXT(nameTextField.text), _("<<YOUR NAME HERE>>"));
+			clutter_text_set_text(CLUTTER_TEXT(genderTextField.text), _("<<YOUR GENDER HERE>>"));
+		}		
+		hobbiesTextField.handler_id = g_signal_connect_swapped(hobbiesTextField.text, "text-changed", (GCallback)limit_line_count, &hobbiesTextField);
+		nameTextField.handler_id = g_signal_connect_swapped(nameTextField.text, "text-changed", (GCallback)limit_line_count, &nameTextField);
 		genderTextField.handler_id = g_signal_connect_swapped(genderTextField.text, "text-changed", (GCallback)limit_line_count, &genderTextField);					
-	
-		avatar_id = gems_profile_manager_get_avatar_id(NULL);
+		avatar_id = /*gems_profile_manager_get_avatar_id(NULL)*/TEST_USERID;
 	
 		if(avatar_id != 0){
 			community_get_avatar(&avatar_static, avatar_id);
+			
 			if(avatar_static.hair != 0){
 				char *temp = strstr(clutter_actor_get_name(avatar_static.hair), "hairs/");
 				temp = strpbrk(temp, "/");
@@ -96,15 +124,23 @@ void start_avatar_editor(){
 				strcpy(currentHairType, temp);
 			}
 		}
-	
+		
 		set_avatar(&avatar_static, CLUTTER_ACTOR(avatarImage_static), CLUTTER_ACTOR(instrumentBackground_static), "avatar-widgets");
-	
 	}
 
-
 }
 
-
+/*
+* Sets avatar picture and other widgets 
+*
+* parameters:
+* -avatar    Avatar struct that contains avatar parts
+* -avatarImage   Container where to put avatar parts
+* -instrumentBackground   Background for favourite instrument image
+* -widget     Other widgets to show (i.e. "avatar-widgets" in avatar_editor.json or 
+*									 "user-profile-widgets" in profile_viewer.json
+*
+*/
 void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrumentBackground, char *widget){
 
 	gchar* default_body_filename = g_strdup_printf("%s/communitymenu/AVATAR_PARTS/bodys/body_blue.png", DATA_DIR);
@@ -129,7 +165,6 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 
 	}
 	
-	
 	clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), avatar->head);
 	clutter_actor_set_position(avatar->head, 92, 85);
 	
@@ -156,7 +191,6 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 		clutter_actor_raise(avatar->instrument, instrumentBackground);
 	}
 	
-	
 	if(avatar->hair != 0){
 	
 		clutter_container_add_actor(CLUTTER_CONTAINER(avatarImage), avatar->hair);
@@ -205,7 +239,11 @@ void set_avatar(Avatar *avatar, ClutterActor *avatarImage, ClutterActor *instrum
 	g_free(avatarbg_filename);
 
 }
-
+/*
+* Callback function to handle clicks in parts-selection-lists. Takes button clicked
+* as parameter. Button's name should be path to the image of particular avatar part. 
+*
+*/
 static void pressed(ClutterActor *actor){
 
 	char *temp;
@@ -217,9 +255,8 @@ static void pressed(ClutterActor *actor){
 		hairsInList = FALSE;
 		DESTROY_ACTOR(avatar_static.body);
 		avatar_static.body = tangle_texture_new(clutter_actor_get_name(actor));
-		clutter_actor_set_name(avatar_static.body, clutter_actor_get_name(actor));
-		
-		}
+		clutter_actor_set_name(avatar_static.body, clutter_actor_get_name(actor));	
+	}
 		
 	if(strstr(clutter_actor_get_name(actor), hairs_path)){
 	
@@ -233,7 +270,7 @@ static void pressed(ClutterActor *actor){
 		temp++;
 		strcpy(currentHairType, temp);
 		clutter_actor_set_name(avatar_static.hair, clutter_actor_get_name(actor));
-		}	
+	}	
 
 	if(strstr(clutter_actor_get_name(actor), instruments_path)){
 	
@@ -253,6 +290,9 @@ static void pressed(ClutterActor *actor){
 
 }
 
+/*
+* This function is called when body color change button is clicked.
+*/
 gboolean change_body_color_clicked(TangleActor *actor, gpointer data){
 
 	cem_add_to_log("changing body color", J_LOG_DEBUG);
@@ -270,6 +310,9 @@ gboolean change_body_color_clicked(TangleActor *actor, gpointer data){
 	return TRUE;
 }
 
+/*
+* This function is called when hair color change button is clicked.
+*/
 gboolean change_hair_color_clicked(TangleActor *actor, gpointer data){
 
 	char path[150] = DATA_DIR;
@@ -305,13 +348,17 @@ gboolean change_hair_color_clicked(TangleActor *actor, gpointer data){
 	return TRUE;
 }
 
-
+/*
+* This function is called when hair type change button is clicked.
+*/
 gboolean change_hair_type_clicked(TangleActor *actor, gpointer data){
 	change_hair_type();
 	return TRUE;
 }
 
-
+/*
+* Changes hair type in avatar picture
+*/
 void change_hair_type() {
 	
 	cem_add_to_log("changing hair type", J_LOG_DEBUG);
@@ -337,6 +384,9 @@ void change_hair_type() {
 		cem_add_to_log("can't open directory containing avatar parts", J_LOG_ERROR);
 }
 
+/*
+* This function is called when head change button is clicked.
+*/
 gboolean change_head_clicked(TangleActor *actor, gpointer data){
 
 	char path[150] = DATA_DIR;
@@ -364,7 +414,9 @@ gboolean change_head_clicked(TangleActor *actor, gpointer data){
 	return TRUE;
 }
 
-
+/*
+* This function is called when instrument change button is clicked.
+*/
 gboolean change_instrument_clicked(TangleActor *actor, gpointer data){
 
 	cem_add_to_log("changing instrument", J_LOG_DEBUG);
@@ -383,8 +435,13 @@ gboolean change_instrument_clicked(TangleActor *actor, gpointer data){
 
 //For cleanupping
 static void end_avatar_view() {
+
+	const char* hobbies = clutter_text_get_text(CLUTTER_TEXT(hobbiesTextField.text));
+	const char* username = clutter_text_get_text(CLUTTER_TEXT(nameTextField.text));
+	const char* gender = clutter_text_get_text(CLUTTER_TEXT(genderTextField.text));
 	
-	community_save_avatar(&avatar_static);
+	guint32 id = community_save_avatar(&avatar_static);
+	update_avatar(TEST_USERID/*id*/, username, hobbies, gender);
 	
 	clear_container(partsList);
 	
@@ -395,11 +452,68 @@ static void end_avatar_view() {
 	DESTROY_ACTOR(instrumentBackground_static);
 	
 	partsList = 0;
-	avatarImage_static = 0;
-	
-	
+	//avatarImage = 0;	
+		
 }
 
+/*
+* Writes avatar info into file.
+*/
+gboolean update_avatar(guint32 id, const char *username, const char *hobbies, const char *gender){
+
+	gchar* user_profile_for_user = g_strdup_printf("%s/user_%d.csv", configure_get_jammo_directory(), id); 
+	gchar* user_profile_for_others = g_strdup_printf("%s/user_%d.json", configure_get_temp_directory(), id);
+	
+	FILE *f;
+	if ((f = fopen(user_profile_for_user, "w")) == NULL) {
+		cem_add_to_log("Error happened while trying to write user .json file", J_LOG_ERROR);
+		printf("Error happened while trying to write a file\n");
+		return FALSE;
+	}else{
+		fprintf(f, "%d,%s,%s,%s", id, username, hobbies, gender);
+	}
+	fclose(f);
+
+	FILE *pFile;
+	if ((pFile = fopen(user_profile_for_others, "w")) == NULL) {
+		cem_add_to_log("Error happened while trying to write user .json file", J_LOG_ERROR);
+		printf("Error happened while trying to write a file\n");
+		return FALSE;
+	}else{
+		fprintf(pFile, "{\n"); 
+		fprintf(pFile, "\"user_properties\":\n");
+		fprintf(pFile, "{\n"); 
+		fprintf(pFile, "\"userid\": \"%d\",\n", id);
+		fprintf(pFile, "\"username\": \"%s\",\n", username);
+		fprintf(pFile, "\"hobbies\": \"%s\",\n", hobbies);
+		fprintf(pFile, "\"gender\": \"%s\"\n", gender);
+       		fprintf(pFile, "}\n"); 			
+		fprintf(pFile, "}"); 
+	}
+	fclose(pFile);	
+
+	if(!sendJammoUserProfile(user_profile_for_others)){
+		printf("Failed to send user profile to server\n");
+		return FALSE;
+	} 
+	
+	g_free(user_profile_for_user);
+	g_free(user_profile_for_others);
+
+	return TRUE;
+}
+
+
+gboolean sendJammoUserProfile(gchar* user_profile)
+{
+	gboolean returnvalue = TRUE;
+	
+	//TODO: Upload file to server
+		
+	return returnvalue;
+}
+
+
 gboolean avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	end_avatar_view();
