@@ -16,9 +16,7 @@
 int create_emma(int motionBuffer[BUFFER_SIZE][3]) {
    FILE *emma_F;
    char *xml_filename;
-   gchar* jammo_directory=configure_get_jammo_directory();
-   xml_filename =  g_strdup_printf("%s/emma.xml",jammo_directory);
-   g_free(jammo_directory);
+   xml_filename =  g_strdup_printf("%s/emma.xml",configure_get_jammo_directory());
    emma_F = fopen (xml_filename, "w");
    int i;
    fprintf(emma_F, "<emma:emma version=\"1.0\" xmlns:emma=\"http://www.w3.org/2003/04/emma\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"xsi:schemaLocation=\"http://www.w3.org/2003/04/emma http://www.w3.org/TR/2009/REC-emma-20090210/emma.xsd\" xmlns=\"http://www.example.com/example\">\n<emma:sequence id=\"N900face\">\n ");
@@ -34,9 +32,7 @@ int create_emma(int motionBuffer[BUFFER_SIZE][3]) {
 int create_emma_int(int interpretation) {
    FILE *emma_F;
    char *xml_filename;
-   gchar* jammo_directory=configure_get_jammo_directory();
-   xml_filename =  g_strdup_printf("%s/emma-int.xml",jammo_directory);
-   g_free(jammo_directory);
+   xml_filename =  g_strdup_printf("%s/emma-int.xml",configure_get_jammo_directory());
    emma_F = fopen (xml_filename, "w");
    fprintf(emma_F, "<emma:emma version=\"1.0\" xmlns:emma=\"http://www.w3.org/2003/04/emma\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"xsi:schemaLocation=\"http://www.w3.org/2003/04/emma http://www.w3.org/TR/2009/REC-emma-20090210/emma.xsd\" xmlns=\"http://www.example.com/example\">\n<emma:sequence id=\"N900face\">\n ");
    if (interpretation == 0){
