@@ -21,6 +21,7 @@
 
 #include "jammer_view.h"
 #include "../../configure.h"
+#include "startmenu.h"
 
 #include "sequencer.h"
 //All global vars Jammer uses TODO: remember to sync with g_free after exit (!important).
@@ -635,7 +636,9 @@ gboolean jammer_gohome_button (TangleActor* actor, gpointer data){
 	clutter_actor_hide(btnSet4);
 	//g_free(instr);
 	clutter_actor_hide(jammo_get_actor_by_id("jammer-view"));
-	return_to_fullsequencer_gui();
+	tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("jammer-view")));
+	startmenu_goto_startmenu(NULL,NULL);
+	//return_to_fullsequencer_gui();
 	return TRUE;
 }
 
@@ -1008,7 +1011,7 @@ start_jammer ()
 	isJammerPlaying = TRUE;
 	isJammerRecording = FALSE;
 	isJammerSeqPlaying = FALSE;
-	jammer_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
+	jammer_sequencer = jammo_sequencer_new();// JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	jammer_editing_track = jammo_editing_track_new(); 
 	jammo_sequencer_add_track (jammer_sequencer, JAMMO_TRACK (jammer_editing_track));
 	guint jammerFreq = 100; ///how often jammer reads values and calcs TODO: adjust it to current sound latency
