@@ -4,7 +4,6 @@ License: GPLv2, read more from COPYING
 This file contains the functionality of JamMo Sounds menu.
  */
 
-
 #include "startmenu.h"
 #include <string.h>
 #include "jammosounds.h"
@@ -15,14 +14,16 @@ static void autoscroll_to_correct_pos(ClutterActor *listToScroll);
 
 static ClutterContainer *list = 0;
 static gint listItemHeight = 0;
+GList *loops = 0;
 
 
 void start_jammosounds(){
 
-
+	GList* l = NULL; //Iterator
 	int numberOfLoops = 0; //this should contain the number of loops in the list
+	loops = 0;
 
-	cem_add_to_log("Starting JamMoSounds", J_LOG_DEBUG);
+	cem_add_to_log("Starting JamMoSounds", J_LOG_DEBUG); 
 
 	ClutterActor* mainview;
 	
@@ -30,36 +31,37 @@ void start_jammosounds(){
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 	
 	ClutterActor* jammosounds_view = jammo_get_actor_by_id("jammosounds-view");
+
 	if(jammosounds_view){
 
-		clutter_actor_show(CLUTTER_ACTOR(jammosounds_view));
-
+		load_loops_from_server(); //Get loops
 		
-		if(numberOfLoops > 5)
+		numberOfLoops = g_list_length(loops);
+
+		clutter_actor_show(CLUTTER_ACTOR(jammosounds_view));
+		
+		if(numberOfLoops > 5){
 			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosounds-songs-list-scrollable"));	
-
-		else
+		}else{
 			list = CLUTTER_CONTAINER(jammo_get_actor_by_id("jammosounds-songs-list-unscrollable"));	
-
-
-		for(int i = 0; i < numberOfLoops; i++){
-			add_loop_to_list(NULL, i);	
 		}
-			
 
-	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list), TANGLE_TYPE_SCROLL_ACTION);
+		for(l = loops; l; l = l->next){
+			add_loop_to_list(l->data, numberOfLoops);	
+		}
 
+		ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(list), TANGLE_TYPE_SCROLL_ACTION);
+		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), list);
 	
-	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(autoscroll_to_correct_pos), list);
-
-	
-	}
-	else
+	}else{
 		cem_add_to_log("can't find 'jammosounds-view' ", J_LOG_ERROR);
+	}
 }
 
 
-gboolean add_loop_to_list(char* name, int numberOfLoops){
+gboolean add_loop_to_list(gpointer data, int numberOfLoops){
+
+	loop_type *loop = data;
 	
 	gchar* listImage_filename = g_strdup_printf("%s/communitymenu/community_jammosounds_bar.png", DATA_DIR);
 	gchar* importButton_filename = g_strdup_printf("%s/communitymenu/community_icon_toloopgame.png", DATA_DIR);
@@ -94,9 +96,9 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 	clutter_container_add_actor(listContainer, instrument);
 	g_free(instrument_filename);
 	
-	text = clutter_text_new_with_text(TEXT_NORMAL, "Loop name here");	
+	text = clutter_text_new_with_text(TEXT_NORMAL, loop->loopname);	
 	loopName = tangle_button_new_with_background_actor(text);
-	clutter_actor_set_name(loopName, "Loop name here");
+	clutter_actor_set_name(loopName, loop->filename);
 
 	clutter_actor_set_position(loopName, 230, listItemHeight/5*2);
 	clutter_container_add_actor(listContainer, loopName);	
@@ -128,67 +130,84 @@ gboolean add_loop_to_list(char* name, int numberOfLoops){
 
 }
 
+void clear_loops(GList* loops_){
 
-void autoscroll_to_correct_pos(ClutterActor *listToScroll){
+	loops_ = g_list_first(loops_);
+	loop_type *temp = 0;
 
+	if(loops_ != NULL)
+	{
+		temp = loops_->data;
 
-	gint slot;
-	gfloat not_used, offset;
-	ClutterAction *action = tangle_actor_get_action_by_type(listToScroll, TANGLE_TYPE_SCROLL_ACTION);
+		if(temp->loopid != NULL)
+			free(temp->loopid);
+			
+		if(temp->filename != NULL)
+			free(temp->filename);
+
+		if(loops_->data != NULL)
+			free(loops_->data);
 	
+		while(loops_->next != NULL)
+		{
+			loops_ = loops_->next;			
+			temp = loops_->data;
 
+			if(temp->loopid != NULL)
+			free(temp->loopid);
+			
+			if(temp->filename != NULL)
+				free(temp->filename);
+
+			if(loops_->data != NULL)
+				free(loops_->data);				
+		}
+	g_list_free(loops_);
+	loops_ = NULL;
 	
-	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(action), &not_used, &offset);
-	slot = (gint)offset % (gint)listItemHeight < listItemHeight/2  	? (gint)(offset) / listItemHeight  
-							  		: (gint)(offset) / listItemHeight + 1;
-
-	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", 
-				(gfloat)(slot*listItemHeight), NULL);
-
-
+	}//if
 }
 
-
 void import_selected_loop(ClutterActor *loop){
 
-	GList *children = clutter_container_get_children(list);
-	int first = 0;
-
-	if(children != NULL){
-		
-		do{
-			if(first == 0)
-				first++;
-			else	
-				children = children->next;
-				
-		
-			if(loop == children->data){
-				//TODO: import selected loop
-				break;
-			}
-		
-		}while(children->next != NULL);
-	
-	}
-	
-	ClutterActor *text = clutter_text_new_with_text(TEXT_NORMAL, "TEST");
-	
-	clutter_container_add_actor(children->data, text);
-	
-	//clutter_container_remove_actor(list, children->data); // JUST TESTING
+	const char* filepath = clutter_actor_get_name(loop);
 
+	printf("jammosounds: %s\n", filepath);
 	cem_add_to_log("Importing loop...", J_LOG_DEBUG);
 
-	g_list_free(children);
+	clear_loops(loops);
+	clear_container(list);
 
+	//TODO: check if loop already exists in hd
+	//TODO: download loop.ogg from server
 }
 
+gboolean load_loops_from_server() 
+{	
+	gboolean returnvalue = FALSE;
+	
+	//TODO: load all_loops.json from server and check that the file was received
+	
+	char * all_loops_filepath = g_strdup_printf("%s/all_loops.json", configure_get_temp_directory()); //Only for testing!
+	int type = 0; //loops
+	
+	if(parse_songs_from_file(all_loops_filepath, &loops, type))
+		returnvalue = TRUE;
+	else
+		returnvalue = FALSE;
 
+	g_free(all_loops_filepath);
+	
+	//TODO: download user profiles etc.?
+		
+	return returnvalue;
+}
 
 gboolean end_jammosounds(TangleButton *tanglebutton, gpointer none){
 
 	clear_container(list);
+
+	clear_loops(loops);
    
 	if(strcmp(clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton)), "gotocommunity") == 0)
 		startmenu_goto_communitymenu(tanglebutton, none);
@@ -199,4 +218,18 @@ gboolean end_jammosounds(TangleButton *tanglebutton, gpointer none){
 	return TRUE;
 }
 
+void autoscroll_to_correct_pos(ClutterActor *listToScroll){
+
+	gint slot;
+	gfloat not_used, offset;
+	ClutterAction *action = tangle_actor_get_action_by_type(listToScroll, TANGLE_TYPE_SCROLL_ACTION);
+	
+	tangle_scroll_action_get_offsets(TANGLE_SCROLL_ACTION(action), &not_used, &offset);
+	slot = (gint)offset % (gint)listItemHeight < listItemHeight/2  	? (gint)(offset) / listItemHeight  
+							  		: (gint)(offset) / listItemHeight + 1;
+
+	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", 
+				(gfloat)(slot*listItemHeight), NULL);
+
+}
 
