@@ -3,6 +3,10 @@ License: GPLv2, read more from COPYING
 
 This file contains the functionality of mysongs menu.
  */
+#include <glib-object.h>
+#include <json-glib/json-glib.h>
+#include <json-glib/json-gobject.h>
+
 #include <tangle.h>
 #include <string.h>
 #include "communitymenu.h"
@@ -10,14 +14,13 @@ This file contains the functionality of mysongs menu.
 #include "../jammo.h"
 #include "mysongs.h"
 #include "community_utilities.h"
-#include "../../gems/community_server_functions.h"
 #include "record_cover_tool.h"
 #include "../../configure.h"
 #include "../../cem/cem.h"
 #include "../file_helper.h"
 #include "../jammo-mentor.h"
 #include "single_thread.h"
-#include "sequencer.h" //From mysongs to sequencer
+#include "sequencer.h" //From mysongs to sequencer 
 
 ClutterContainer* remove_view = 0;
 ClutterColor mysongs_text_color = { 255, 255, 255, 255 };
@@ -25,8 +28,13 @@ static list_type songlist = {0, 0};
 static gboolean removing_song = FALSE;
 static gchar* command;
 ClutterActor *currentlyModifiedLabel = 0;
+GList* all_songs = 0;
+gint song_index = 0;
 
-void start_mysongs()
+/**
+ * Starts mysongs view
+**/
+void start_mysongs() 
 {
 	cem_add_to_log("Starting Mysongs", J_LOG_DEBUG);
 
@@ -46,10 +54,16 @@ void start_mysongs()
 	else 	cem_add_to_log("can't find 'mysongs-view' ", J_LOG_ERROR);
 }
 
+/**
+ * Ends mysongs and clears all containers
+**/
 void mysongs_end_mysongs(){
 
 	clear_container(songlist.list);
 
+	clear_songlist(all_songs);
+	all_songs = NULL;
+
 	if(removing_song){
 		clear_container(remove_view);
 		removing_song = FALSE;
@@ -57,7 +71,6 @@ void mysongs_end_mysongs(){
 
 }
 
-
 gboolean mysongs_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	mysongs_end_mysongs();
@@ -78,6 +91,10 @@ gboolean mysongs_mentor_clicked (TangleButton *tanglebutton, gpointer data)
 	return TRUE;
 }
 
+
+/**
+ * Function to continue project in sequencer
+**/
 void start_sequencer_with_this_file(ClutterActor *actor, gpointer none) 
 {
 	mysongs_end_mysongs();
@@ -94,9 +111,9 @@ void start_sequencer_with_this_file(ClutterActor *actor, gpointer none)
  * 2=workshop in progress
  * 3=song is sent to jammosongs
  *
- *TODO: filename is just printed.
+ * Adds files to list
  */
-gboolean mysongs_add_loop_to_list(char* filename, int type)
+gboolean mysongs_add_loop_to_list(char* filename, int type, gchar* json_param)
 {
 	ClutterActor *colorbar 		= 0;
 	ClutterActor *label 		= 0;
@@ -140,6 +157,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	int j 		= 0;
 	int type_length = 0;
 	int path_length = 0;
+	int userid_length = 10;
 	int length	= strlen(filename);
 
 	char temp[length];
@@ -154,7 +172,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 		type_length = 4; //.ogg
 	}
 		
-	for(i = path_length + 1; i < length-type_length; i++)
+	for(i = path_length + 1; i < (length-(type_length + userid_length)); i++)
 	{
 		filename_for_textbutton[j] = temp[i];
 		j++;
@@ -164,9 +182,9 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	//TODO: change gems_profile_manager_get_userid(NULL) to use proper user id
 
 	command = g_strdup_printf("ls %s/label_%d_%s.csv 1> /dev/null 2> /dev/null", configure_get_jammo_directory(), 
-					gems_profile_manager_get_userid(NULL), filename_for_textbutton);
+					/*gems_profile_manager_get_userid(NULL)*/TEST_USERID, filename_for_textbutton);
 
-	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), gems_profile_manager_get_userid(NULL), 
+	path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), /*gems_profile_manager_get_userid(NULL)*/TEST_USERID, 
 					filename_for_textbutton);
 
 	gchar* labelButton_filename = g_strdup_printf("%s/communitymenu/community_cdlabel_small.png", DATA_DIR);
@@ -235,21 +253,24 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 
 			g_signal_connect(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK (start_sequencer_with_this_file), CLUTTER_ACTOR(infoButton));
 			clutter_actor_set_position(infoButton, 690, 7);
+			clutter_actor_set_name(infoButton,filename);
 			break;
 		case 1:
 			strcat(infoButton_path, "/communitymenu/community_umsic_icon.png");
 			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(infoButton_path));
 
 			clutter_actor_set_position(infoButton, 690, 15);
+			clutter_actor_set_name(infoButton,filename);
 
-			g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_comment), CLUTTER_ACTOR(infoButton));
+			g_signal_connect_swapped(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_send_song), CLUTTER_ACTOR(textButton));
 			
 			break;
 		case 3:
 			strcat(infoButton_path, "/communitymenu/community_comment_icon.png");
 			infoButton = tangle_button_new_with_background_actor(tangle_texture_new(infoButton_path));
+			clutter_actor_set_name(infoButton,json_param);
 
-			g_signal_connect(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_get_comments), CLUTTER_ACTOR(infoButton));
+			g_signal_connect(CLUTTER_ACTOR(infoButton), "clicked", G_CALLBACK(mysongs_get_comments), infoButton); 
 			clutter_actor_set_position(infoButton, 690, 15);				
 			break;
 	}
@@ -271,7 +292,7 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 		clutter_actor_set_name(labelButton, path);
 		g_signal_connect_swapped(CLUTTER_ACTOR(labelButton), "clicked", G_CALLBACK(mysongs_label_button_clicked), CLUTTER_ACTOR(labelButton));
 	}
-	clutter_actor_set_name(infoButton,filename);
+	//clutter_actor_set_name(infoButton,filename);
 
 	clutter_actor_set_name(remove_button,filename);
 	clutter_actor_set_position(remove_button, 580, 15);
@@ -287,10 +308,12 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	
 	clutter_container_add_actor(listContainer, CLUTTER_ACTOR(infoButton));
 
+
 	g_signal_connect(textButton, "clicked", G_CALLBACK(song_on_clicked_function), NULL);
 	g_object_set(textButton, "hold-timeout", 1500, NULL);
 	g_signal_connect(textButton, "held", G_CALLBACK(song_on_held_function), NULL);
 
+
 	g_signal_connect_swapped(CLUTTER_ACTOR(remove_button), "clicked", G_CALLBACK(mysongs_remove_song_view), CLUTTER_ACTOR(textButton));
 	g_signal_connect_swapped(CLUTTER_ACTOR(label), "clicked", G_CALLBACK(show_song_label), filename);	
 
@@ -301,31 +324,275 @@ gboolean mysongs_add_loop_to_list(char* filename, int type)
 	return TRUE;
 }
 
-void mysongs_get_comments(ClutterActor* song)
+/**
+ * Views comments of chosen song
+**/
+void mysongs_get_comments(ClutterActor* json_)
 {
+	const gchar* comments_path = clutter_actor_get_name(json_); 
 
-	GList *messages = 0;
+	if(comments_path != NULL){
+
+		//TODO: Download messages.json from server! 
+
+		mysongs_end_mysongs();
+		ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
+		clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 	
-	//TODO: get comments of the song from the server
-	
-	mysongs_end_mysongs();
-	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_get_actor_by_id("mysongs-view")));
-	
-	start_thread_view(messages, "mysongs", NULL, 0);
+		start_thread_view("mysongs", comments_path, 0);
+	}else{
+		printf("myongs_get_comments error: bad filename\n");
+	}
+
 }
 
-void mysongs_comment(ClutterActor *actor)
+
+/**
+ * Writes json files that are needed for sending song to server 
+**/
+void mysongs_send_song(ClutterActor *actor)
 {
-	const gchar * filename = clutter_actor_get_name(actor);
+	printf("mysongs_send_song\n");
+
+	//TODO: filenames for jsons!
+	
+	//TODO: Get all_songs.json from the server
+	if(!load_file_from_server("all_songs.json")){
+		printf("Couldn't download all_songs.json from server for writing!\n");
+		return;
+	}
+	char *all_songs_filepath = g_strdup_printf("%s/all_songs.json", configure_get_temp_directory()); //Only for testing!
+
+	FILE *commentsFile;
+	gboolean coverFound = FALSE;
+	ClutterActor *text = tangle_button_get_normal_background_actor(TANGLE_BUTTON(actor));
+	const gchar * songname = clutter_text_get_text(CLUTTER_TEXT(text));
+	time_type now;
+	now = get_current_time();
+	
+	char * cover = "";
+	char * songid = "";
+	const char * filename = clutter_actor_get_name(actor); 
+	guint32 userid = /*gems_profile_manager_get_userid(NULL)*/TEST_USERID;
+	char * date = now.time;
+	
+	songid = g_strdup_printf("%d_%s", userid, songname); 	
+	char * comments = g_strdup_printf("%s/messages_%s.json", configure_get_temp_directory(), songid); 
+	char * label_path = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), userid, songname);
+	
+	if(file_exist(label_path)){ // check whether labelfile exists	
+		coverFound = TRUE;
+		
+		if(mysongs_copy_label(label_path, userid, songname)) //we copy the labelfile to temp directory for sending
+			cover = g_strdup_printf("%s/label_%d_%s.csv", configure_get_temp_directory(), userid, songname);
+	}
+	g_free(label_path);
+	
+	//write comments file
+	if ((commentsFile = fopen(comments, "w")) == NULL) {
+			cem_add_to_log("Error happened while trying to write comments file", J_LOG_ERROR);
+			printf("Error happened while trying to write comments file\n");
+			return;
+	}
+	fclose(commentsFile);
+
+	FILE * pFile;
+	gboolean fileIsEmpty = FALSE;
+	
+	//check whether json file is empty
+	if ((pFile = fopen(all_songs_filepath, "r")) == NULL) 
+		//cem_add_to_log("Error happened while trying to read all_songs.json", J_LOG_ERROR);
+		//printf("Error happened while trying to read a file\n");
+		//return;	
+
+		if((pFile = fopen(all_songs_filepath, "w")) == NULL){
+			cem_add_to_log("Error happened while trying to write all_songs.json", J_LOG_ERROR);
+			printf("Error happened while trying to write all_songs.json\n");
+			return;
+		}
+	
+	if(fgetc(pFile) == EOF)
+		fileIsEmpty = TRUE;		
+
+	fclose(pFile);
+
+	char * dest_filepath = g_strdup_printf("%s/temp.json", configure_get_temp_directory());
+
+	if(fileIsEmpty){
+
+		//write a new json file
+		if ((pFile = fopen(all_songs_filepath, "w")) == NULL) {
+			cem_add_to_log("Error happened while trying to write into all_songs.json", J_LOG_ERROR);
+			printf("Error happened while trying to write a file\n");
+			return;
+		}else{
+			fprintf(pFile, "{\n"); 
+			fprintf(pFile, "\"tracks\": [\n");
+			fprintf(pFile, "{\n"); 
+			fprintf(pFile, "\"songid\": \"%s\",\n", songid);
+			fprintf(pFile, "\"songname\": \"%s\",\n", songname);
+			fprintf(pFile, "\"userid\": \"%d\",\n", userid);
+			fprintf(pFile, "\"filename\": \"%s\",\n", filename);
+			//fprintf(pFile, "\"json\": \"%s\",\n", json);
+			fprintf(pFile, "\"cover\": \"%s\",\n", cover);
+			fprintf(pFile, "\"comments\": \"%s\",\n", comments);
+			fprintf(pFile, "\"date\": \"%s\"\n", date);
+       	 		fprintf(pFile, "}\n"); 		
+			fprintf(pFile, "]\n"); 	
+			fprintf(pFile, "}"); 
+		}
+		fclose(pFile);	
+	}else{
+		
+		//update json file
+		FILE *destFile;
+		int c, position_found = 0;
+		
+		//open source file
+		if((pFile = fopen(all_songs_filepath, "r")) == NULL){
+			printf("Error happened while trying to open source file (all_songs.json)\n");
+			return;
+		}
+		//open destination file
+		if((destFile = fopen(dest_filepath, "w")) == NULL){
+			printf("Error happened while trying to open destination file (temp.json)\n");
+			return;
+		}	
+		//copy the file
+		fprintf(destFile, "{\n"); 
+		fprintf(destFile, "\"tracks\": [");
+		
+		do{
+			c = fgetc(pFile);
+			if(ferror(pFile)) {
+      				printf("Error reading source file (all_songs.json)\n");
+      				return;
+    			}
+			if(c == '[')
+				position_found = 1;
+			
+			if(position_found == 1 && c != '[' && c != ']'){
+				if(c != ']') fputc(c, destFile);
+				if(ferror(destFile)) {
+      					printf("Error writing destination file (temp.json)\n");
+      					return;
+				}
+			}
+		}while(c != ']');	
+		fclose(pFile);	
+	
+		fprintf(destFile, ",\n");
+		fprintf(destFile, "{\n"); 
+		fprintf(destFile, "\"songid\": \"%s\",\n", songid);
+		fprintf(destFile, "\"songname\": \"%s\",\n", songname);
+		fprintf(destFile, "\"userid\": \"%d\",\n", userid);
+		fprintf(destFile, "\"filename\": \"%s\",\n", filename);
+		//fprintf(destFile, "\"json\": \"%s\",\n", json);
+		fprintf(destFile, "\"cover\": \"%s\",\n", cover);
+		fprintf(destFile, "\"comments\": \"%s\",\n", comments);
+		fprintf(destFile, "\"date\": \"%s\"\n", date);
+       		fprintf(destFile, "}\n");	      	 	
+		fprintf(destFile, "]\n"); 	
+		fprintf(destFile, "}"); 	 	
+		fclose(destFile);
+		
+		if(remove(all_songs_filepath) != 0){ //We remove the original json
+			printf("Error removing original all_songs.json\n");
+			return;
+		}			
+		rename(dest_filepath, all_songs_filepath); //And rename temp file with the name of the original
+		
+	}//Json file is ready
 
 	gchar * message = g_strdup_printf("Sending song \"%s\" to JamMo Songs...", filename);
 	cem_add_to_log(message, J_LOG_DEBUG);
 	g_free(message);
+	
+	if(sendJammoSong(filename, cover, comments, all_songs_filepath))
+		printf("sendJammoSong ok\n");
 
-	//sendJammoFile(filename); //TODO: Send song to JamMo Songs
+	if(coverFound)
+		g_free(cover);
+	
+	g_free(all_songs_filepath);
+	g_free(dest_filepath);
+	g_free(songid);
+	g_free(comments);
 }
 
 
+/**
+ * Sends a song to server
+**/
+gboolean sendJammoSong(const char *song_filename, const char *song_cover, const char *comments_file, const char *all_songs_json)
+{
+	gboolean returnvalue = TRUE;
+		
+	//TODO: Send song.ogg, cover.csv(if != ""), comments.json and all_songs.json to server 
+	
+	//TODO: Check that files where successfully sended
+	
+	//TODO: Remove jsons from hd
+
+	if(returnvalue == TRUE){
+		clear_container(songlist.list);
+		mysongs_refresh_list();
+	}		
+
+	return returnvalue;
+}
+
+
+/**
+ * Searches a song of given name from all_songs.json. This function is used to check whether the song has been sended to JammoSongs. 
+**/
+gboolean find_song_by_filename(char* songName, GList* songlist_param){
+
+	gboolean songWasFound = FALSE;
+	GList* l = NULL; //Iterator
+
+	int numberOfFoundSongs = g_list_length(songlist_param);
+	int i = 0, j = 0, songlist_index = 0;
+	int type_length = strlen(".ogg");
+	int path_length = strlen(configure_get_finalized_directory());
+	int userid_length = 10;
+	int filename_length = strlen(songName);
+	char temp[filename_length];
+	char real_songname[filename_length];
+
+	strcpy(temp, songName);
+		
+	for(i = path_length + 1; i < (filename_length-(type_length + userid_length)); i++){
+		real_songname[j] = temp[i];
+		j++;
+	}
+	real_songname[j] = 0;
+
+	//build songid for the song
+	char* songid = g_strdup_printf("%d_%s", TEST_USERID, real_songname);
+	
+	if(numberOfFoundSongs > 0){
+	
+		for (l = songlist_param; l; l = l->next){
+			
+			if(strcmp(((song_type*)l->data)->songid, songid) == 0){ //search with songid
+				songWasFound = TRUE;
+				song_index = songlist_index;
+			}
+			songlist_index++;		
+		}//for
+	}else{
+		printf("songlist is empty\n");
+	}
+	g_free(songid);
+
+	return songWasFound;
+}
+
+
+/**
+ * Deletes a song from list and hard-drive 
+**/
 void mysongs_delete_song(ClutterActor *actor)
 {
 	const gchar * filename = clutter_actor_get_name(actor);
@@ -341,7 +608,7 @@ void mysongs_delete_song(ClutterActor *actor)
 	songname[i] = 0;
 	
 	//TODO: change gems_profile_manager_get_userid(NULL) to use proper user id
-	gchar* label = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), gems_profile_manager_get_userid(NULL), songname);
+	gchar* label = g_strdup_printf("%s/label_%d_%s.csv", configure_get_jammo_directory(), /*gems_profile_manager_get_userid(NULL)*/TEST_USERID, songname);
 
 	gchar * message = g_strdup_printf("Removing %s...", filename);
 	cem_add_to_log(message, J_LOG_DEBUG);
@@ -366,12 +633,19 @@ void mysongs_delete_song(ClutterActor *actor)
 }
 
 
+/**
+ * Cancels song delete
+**/
 void mysongs_cancel_song_delete(ClutterActor *actor)
 {
 	removing_song = FALSE;
 	clear_container(remove_view);
 }
 
+
+/**
+ * Sets up question whether to remove a song or not
+**/
 void mysongs_remove_song_view(ClutterActor *actor){
 
 	if(removing_song) return;
@@ -406,30 +680,44 @@ void mysongs_remove_song_view(ClutterActor *actor){
 	g_free(cancel_button_filename);
 }
 
-void mysongs_label_button_clicked(ClutterActor *label){
 
+/**
+ * This function is called to start label editor
+**/
+void mysongs_label_button_clicked(ClutterActor *label)
+{
 	currentlyModifiedLabel = label;
-	
 	start_record_cover_tool(clutter_actor_get_name(label));
 }
 
-
+/**
+ * Upadates label button after it has been changed
+**/
 void mysongs_update_label_button(const gchar* path){
 
 	currentlyModifiedLabel = tangle_button_new_with_background_actor(clutter_rectangle_new_with_color(clutter_color_new(255,255, 255,255)));
 	mysongs_refresh_list();
 }
 
+
+/**
+ * Refreshes list after it has been updated
+**/
 void mysongs_refresh_list()
 {
 	int numberOfLoops = 0;
 	GList* l = NULL; //Iterator
 	GList* projects = NULL;
 	GList* finalized = NULL;
+	all_songs = 0;
 
 	cem_add_to_log("Refreshing list...", J_LOG_DEBUG);
 	
 	clear_container(songlist.list);
+	
+	//TODO: download all_songs.json from server
+	gchar* all_songs_path = g_strdup_printf("%s/all_songs.json", configure_get_temp_directory()); //Only for testing!
+	parse_songs_from_file(all_songs_path, &all_songs, 1);
 
 	projects = file_helper_get_all_files(configure_get_projects_directory()); //Project-files
 	finalized = file_helper_get_all_files(configure_get_finalized_directory()); //Audio-files
@@ -444,10 +732,16 @@ void mysongs_refresh_list()
 	clutter_actor_lower(CLUTTER_ACTOR(songlist.list),jammo_get_actor_by_id("mysongs_down-index"));
 
 	for (l = projects; l; l = l->next)
-		mysongs_add_loop_to_list(l->data, 0); //0 = Project-file
+		mysongs_add_loop_to_list(l->data, 0, NULL); //0 = Project-file
 
 	for (l = finalized; l; l = l->next)
-		mysongs_add_loop_to_list(l->data, 1); //1 = Finalized file
+		
+		if(find_song_by_filename(l->data, all_songs)){ 
+ 
+			mysongs_add_loop_to_list(l->data, 3, ((song_type*)g_list_nth_data(all_songs, song_index))->comments_path); //3 = File has been sended to JammoSongs
+		}else{
+			mysongs_add_loop_to_list(l->data, 1, NULL); //1 = Finalized file
+		}
 
 	if(numberOfLoops <= 6)
 		clutter_actor_set_height(CLUTTER_ACTOR(songlist.list), songlist.listItemHeight * numberOfLoops);
@@ -457,6 +751,51 @@ void mysongs_refresh_list()
 	ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(songlist.list), TANGLE_TYPE_SCROLL_ACTION);
 
 	g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(community_autoscroll_to_correct_pos), songlist.list); // 2 warnings happens here
+	
+	clear_songlist(all_songs);
+	all_songs = NULL;
+	g_free(all_songs_path);
 
 
 }
+
+/**
+ * Copies a song label to jammo temp directory for sending to server
+**/
+gboolean mysongs_copy_label(gchar* label_param, guint32 userid_param, const gchar* songname_param){
+
+	int c;
+	FILE *pFile;
+	FILE *destFile;
+	gchar* dest_filepath = g_strdup_printf("%s/label_%d_%s.csv", configure_get_temp_directory(), userid_param, songname_param);
+
+	//open source file
+	if((pFile = fopen(label_param, "r")) == NULL){
+		printf("Error happened while trying to open source file '%s'\n", label_param);
+		return FALSE;
+	}		
+	//open destination file
+	if((destFile = fopen(dest_filepath, "w")) == NULL){
+		printf("Error happened while trying to open destination file '%s'\n", dest_filepath);
+		return FALSE;
+	}			
+	//copy the file
+	do{
+		c = fgetc(pFile);
+		if(ferror(pFile)) {
+      			printf("Error reading source file '%s'\n", label_param);
+      			return FALSE;
+    		}
+		if(c != EOF) fputc(c, destFile);
+		if(ferror(destFile)) {
+      			printf("Error writing destination file '%s'\n", dest_filepath);
+      			return FALSE;
+		}
+			
+	}while(c != EOF);
+	fclose(pFile);		 	
+	fclose(destFile);
+
+	g_free(dest_filepath);
+	return TRUE;
+}
