@@ -622,6 +622,9 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 
 	g_object_set(track_view_actor, "sample-color", &sample_color, NULL);
 
+	ClutterColor background_color = { sample_color.red, sample_color.green, sample_color.blue, 68};
+	g_object_set(track_view_actor, "background-color", &background_color, NULL);
+
 	gchar* file_for_label_button = tangle_lookup_filename(name_of_label_button);
 	label = tangle_button_new_with_background_actor(tangle_texture_new(file_for_label_button));
 	g_free(file_for_label_button);
