@@ -35,8 +35,6 @@
 #define BUFFER_SIZE         1000
 #define JAMMOPORT		5555
 
-GTimer* testtimer;
-
 gems_communication_data* gems_communication_init()
 {
 	// Communication data struct
@@ -51,15 +49,12 @@ gems_communication_data* gems_communication_init()
 	// Rejected list
 	data->rejected = NULL;
 	
-	testtimer = g_timer_new();
-	
 	return data;
 }
 
 void gems_communication_cleanup()
 {	
 	gems_communication_data* data = gems_get_data()->communication;
-	g_timer_destroy(testtimer);
 	
 	if(data == NULL) return;
 	
@@ -99,7 +94,6 @@ gint gems_communication_search_jammos()
 {
 	gchar* logmsg = NULL;
 	gems_components* data = gems_get_data();
-	g_timer_start(testtimer);	
 	
 	if(data == NULL) return FALSE;
 	if(gems_get_peerhood() == NULL) return FALSE; // no PeerHood = no network
@@ -156,13 +150,6 @@ gint gems_communication_search_jammos()
 	ph_c_delete_devicelist(list);
 	
 	return TRUE;
-	
-	if(g_timer_elapsed(testtimer, NULL) > 0.020)
-	{
-		logmsg = g_strdup_printf("search_jammos %f",g_timer_elapsed(testtimer,NULL));
-		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-	}
 }
 
 gboolean gems_communication_establish_connection(MAbstractDevice* device)
@@ -245,7 +232,6 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 gint gems_communication_retrieve_profiles()
 {
 	gems_components* data = gems_get_data();
-	g_timer_start(testtimer);
 	
 	if(data == NULL) return FALSE;
 	if(gems_get_peerhood() == NULL) return FALSE;
@@ -304,19 +290,11 @@ gint gems_communication_retrieve_profiles()
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
 	
 	return TRUE;
-	
-	if(g_timer_elapsed(testtimer, NULL) > 0.020)
-	{
-		logmsg = g_strdup_printf("retrieve_profiles %f",g_timer_elapsed(testtimer,NULL));
-		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-	}
 }
 
 gint gems_communication_request_groups()
 {
 	gems_components* data = gems_get_data();
-	g_timer_start(testtimer);
 
 	if(data == NULL) return FALSE;
 	if(gems_get_peerhood() == NULL) return FALSE;
@@ -377,13 +355,6 @@ gint gems_communication_request_groups()
 	
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
 	
-	if(g_timer_elapsed(testtimer, NULL) > 0.020)
-	{
-		logmsg = g_strdup_printf("retrieve_groups %f",g_timer_elapsed(testtimer,NULL));
-		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-	}
-	
 	return TRUE;
 }
 
@@ -395,7 +366,6 @@ gint gems_communication_advert_group()
 	if(gems_get_peerhood() == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
-	g_timer_start(testtimer);
 	gchar* logmsg = NULL;
 	
 	// Group not enabled
@@ -453,13 +423,6 @@ gint gems_communication_advert_group()
 		gems_clear_message(msg);
 	}
 	
-	if(g_timer_elapsed(testtimer, NULL) > 0.020)
-	{
-		logmsg = g_strdup_printf("advert_group %f",g_timer_elapsed(testtimer,NULL));
-		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
-		g_free(logmsg);
-	}
-	
 	return TRUE;
 }
 
@@ -922,8 +885,14 @@ gint gems_communication_process_connected()
 									gems_connection_add_16(element,identifier);
 									break;
 								default:
-									// TODO handle errorous packet type
-									// After a device is authenticated everything should be sent as encrypted data inside envelope
+									/* After a device is authenticated everything should be sent as encrypted data inside envelope
+									 * or as an error message, handle errorous packet type by disconnecting the connection */
+									logmsg = g_strdup_printf("gems_communication_process_list: invalid packet type \"%d\" from device %u.",
+										ntohs(identifier), ph_c_connection_get_device_checksum(element->connection));
+									cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+									g_free(logmsg);
+									ph_c_connection_disconnect(element->connection);
+									cleanup_required = TRUE;
 									break;
 							}
 						}
