@@ -26,31 +26,6 @@ gboolean gems_profile_manager_login(guint32 userId, gchar* username, gchar* pass
 	return profilemanager_login(pm,userId);
 }
 
-// Login with pen gesture
-gboolean gems_profile_manager_login_pen_gesture(guint32 userId, gchar* username, gchar* passworddata)
-{
-	ProfileManager* pm = gems_get_data()->pm;
-	if(pm == NULL) return FALSE;
-	
-	return profilemanager_login(pm,userId);
-}
-
-//Set password
-gboolean gems_profile_manager_set_password(guint32 userId, gchar* username, gchar* passworddata)
-{
-
-	return TRUE;
-}
-
-//Set pen gesture password
-gboolean gems_profile_manager_set_password_pen_gesture(guint32 userId, gchar* username, gchar* passworddata)
-{
-
-	return TRUE;
-}
-
-
-
 gint gems_profile_manager_authenticate_default_user(const gchar* passworddata)
 {
 	profilemanager_storage_clear_profile(gems_get_profile_manager());
