@@ -20,15 +20,6 @@
 // Login
 gboolean gems_profile_manager_login(guint32 userId, gchar* username, gchar* passworddata);
 
-//Login with pen gesture password
-gboolean gems_profile_manager_login_pen_gesture(guint32 userId, gchar* username, gchar* passworddata);
-
-//Set password
-gboolean gems_profile_manager_set_password(guint32 userId, gchar* username, gchar* passworddata);
-
-//Set pen gesture password
-gboolean gems_profile_manager_set_password_pen_gesture(guint32 userId, gchar* username, gchar* passworddata);
-
 gint gems_profile_manager_authenticate_default_user(const gchar* passworddata);
 
 gint gems_profile_manager_authenticate_user(const gchar* username, const gchar* passworddata);
