@@ -37,7 +37,7 @@ gems_message* gems_security_create_envelope(guint16 type,gems_connection* elemen
 	position = position + JAMMO_MESSAGE_DIGEST_SIZE + 1;
 	
 	// Copy original message
-	memcpy(&envelope->message[position],original->message,original->length);
+	g_memmove(&envelope->message[position],original->message,original->length);
 	
 	return envelope;
 }
@@ -53,7 +53,7 @@ gint gems_security_extract_envelope(gems_connection* element)
 	
 	guchar* storedhash = (guchar*)gems_connection_get_data(element,sizeof(guint16)+sizeof(guint32),JAMMO_MESSAGE_DIGEST_SIZE);
 	
-	memmove(&element->nwbuffer[0],
+	g_memmove(&element->nwbuffer[0],
 		&element->nwbuffer[sizeof(guint16) + sizeof(guint32) + JAMMO_MESSAGE_DIGEST_SIZE + 1],
 		(length - sizeof(guint16) - sizeof(guint32) - JAMMO_MESSAGE_DIGEST_SIZE - 1));
 		
