@@ -424,7 +424,7 @@ gboolean gems_group_init_group(gint16 type, gint16 size, gint16 theme)
 		
 		// Start advert
 		
-		g_timeout_add_full(G_PRIORITY_LOW,200,(GSourceFunc)gems_communication_advert_group, data,NULL);
+		data->timeout_functions[11] = g_timeout_add_full(G_PRIORITY_HIGH,200,(GSourceFunc)gems_communication_advert_group, data,NULL);
 		
 		return TRUE;
 	}
