@@ -248,22 +248,22 @@ static void gst_jammo_sampler_class_init (GstJammoSamplerClass * klass)
 
 
 
-static void init_sampler (GstJammoSampler * src, gint index, const gchar *filename, gint loop_start, gint loop_end, gint file_size, gint needed_pitch, gint xfade, gint fade_out){
+static void init_sampler (GstJammoSampler * src, gint index_parameter, const gchar *filename, gint loop_start, gint loop_end, gint file_size, gint needed_pitch, gint xfade, gint fade_out){
 gint i;
 
-src->wav_based_instrument[index]->sampleindex=0;
-src->wav_based_instrument[index]->loop_start=loop_start;
-src->wav_based_instrument[index]->loop_end=loop_end;
-src->wav_based_instrument[index]->file_size=file_size; 
-src->wav_based_instrument[index]->needed_pitch=needed_pitch;
+src->wav_based_instrument[index_parameter]->sampleindex=0;
+src->wav_based_instrument[index_parameter]->loop_start=loop_start;
+src->wav_based_instrument[index_parameter]->loop_end=loop_end;
+src->wav_based_instrument[index_parameter]->file_size=file_size;
+src->wav_based_instrument[index_parameter]->needed_pitch=needed_pitch;
 if (xfade>=0)
-	src->wav_based_instrument[index]->xfade=xfade;
+	src->wav_based_instrument[index_parameter]->xfade=xfade;
 else
-	src->wav_based_instrument[index]->xfade=0;
-src->wav_based_instrument[index]->xfadecounter=-1.0;
-src->wav_based_instrument[index]->released=FALSE;
-src->wav_based_instrument[index]->releasecounter=-1.0;
-src->wav_based_instrument[index]->fade_out=fade_out;
+	src->wav_based_instrument[index_parameter]->xfade=0;
+src->wav_based_instrument[index_parameter]->xfadecounter=-1.0;
+src->wav_based_instrument[index_parameter]->released=FALSE;
+src->wav_based_instrument[index_parameter]->releasecounter=-1.0;
+src->wav_based_instrument[index_parameter]->fade_out=fade_out;
 
 SF_INFO sfinfo;
 sfinfo.format = 0;
@@ -278,11 +278,11 @@ if (sndfileptr==NULL) {
 		if names match change pointer value to that
 		else allocate memory and read data */
 
-src->wav_based_instrument[index]->sampletable =NULL;
+src->wav_based_instrument[index_parameter]->sampletable =NULL;
 
 // samplerate of sample file can be played with correct pitch even if samplerate of a file is
 // different from the samplerate of sampler
-src->wav_based_instrument[index]->original_samplerate=sfinfo.samplerate;
+src->wav_based_instrument[index_parameter]->original_samplerate=sfinfo.samplerate;
 
 // sampler is mono sampler
 if (sfinfo.channels>1) {
@@ -292,31 +292,31 @@ if (sfinfo.channels>1) {
 //printf("\nbefore looking for same sample\n");
 
 for (i=0;i<JAMMOMIDI_NUMBER_OF_NOTES;i++) {
-	if (src->wav_based_instrument[i]->filename!=NULL && strcmp(filename, src->wav_based_instrument[i]->filename)==0 && i!=index) {
-		src->wav_based_instrument[index]->sampletable=src->wav_based_instrument[i]->sampletable;
+	if (src->wav_based_instrument[i]->filename!=NULL && strcmp(filename, src->wav_based_instrument[i]->filename)==0 && i!=index_parameter) {
+		src->wav_based_instrument[index_parameter]->sampletable=src->wav_based_instrument[i]->sampletable;
 		//printf("sampletable pointer ok\n");
-		if (src->wav_based_instrument[index]->filename==NULL)
-			src->wav_based_instrument[index]->filename =malloc((strlen(filename)+1)*sizeof(gchar));
+		if (src->wav_based_instrument[index_parameter]->filename==NULL)
+			src->wav_based_instrument[index_parameter]->filename =malloc((strlen(filename)+1)*sizeof(gchar));
 		else
-			src->wav_based_instrument[index]->filename =realloc(src->wav_based_instrument[index]->filename, (strlen(filename)+1)*sizeof(gchar) );
-		strcpy(src->wav_based_instrument[index]->filename, src->wav_based_instrument[i]->filename);
+			src->wav_based_instrument[index_parameter]->filename =realloc(src->wav_based_instrument[index_parameter]->filename, (strlen(filename)+1)*sizeof(gchar) );
+		strcpy(src->wav_based_instrument[index_parameter]->filename, src->wav_based_instrument[i]->filename);
 	//printf("same sample table used\n");
 	break;
 	}
 }
 
 /* same sample was not already used */
-if (src->wav_based_instrument[index]->sampletable ==NULL) {
+if (src->wav_based_instrument[index_parameter]->sampletable ==NULL) {
 	//printf("allocating memory\n");
-	src->wav_based_instrument[index]->sampletable =malloc(file_size*sizeof(gint16));
-	if (src->wav_based_instrument[index]->filename==NULL)
-		src->wav_based_instrument[index]->filename =malloc((strlen(filename)+1)*sizeof(gchar));
+	src->wav_based_instrument[index_parameter]->sampletable =malloc(file_size*sizeof(gint16));
+	if (src->wav_based_instrument[index_parameter]->filename==NULL)
+		src->wav_based_instrument[index_parameter]->filename =malloc((strlen(filename)+1)*sizeof(gchar));
 	else
-		src->wav_based_instrument[index]->filename =realloc(src->wav_based_instrument[index]->filename, (strlen(filename)+1)*sizeof(gchar) );
-	strcpy(src->wav_based_instrument[index]->filename, filename);
+		src->wav_based_instrument[index_parameter]->filename =realloc(src->wav_based_instrument[index_parameter]->filename, (strlen(filename)+1)*sizeof(gchar) );
+	strcpy(src->wav_based_instrument[index_parameter]->filename, filename);
 	/* read audio data to sample table */
 	if (sndfileptr){
-		if (sf_read_short(sndfileptr, src->wav_based_instrument[index]->sampletable, file_size)!=file_size){
+		if (sf_read_short(sndfileptr, src->wav_based_instrument[index_parameter]->sampletable, file_size)!=file_size){
 			printf("error reading sample file\n");
 			}
 		}
@@ -1091,10 +1091,10 @@ static gboolean gst_jammo_sampler_stop (GstBaseSrc * basesrc)
 static gboolean gst_jammo_sampler_do_seek (GstBaseSrc * basesrc, GstSegment * segment)
 {
   GstJammoSampler *src = GST_JAMMO_SAMPLER (basesrc);
-  GstClockTime time;
+  GstClockTime time_to_seek;
 
   segment->time = segment->start;
-  time = segment->last_stop;
+  time_to_seek = segment->last_stop;
   
 	// seek eventlist to correct position
 	src->time = segment->time;
@@ -1127,16 +1127,16 @@ static gboolean gst_jammo_sampler_do_seek (GstBaseSrc * basesrc, GstSegment * se
 
   /* now move to the time indicated */
   src->next_sample =
-      gst_util_uint64_scale_int (time, src->samplerate, GST_SECOND);
+      gst_util_uint64_scale_int (time_to_seek, src->samplerate, GST_SECOND);
   src->next_byte = src->next_sample * src->sample_size;
   src->next_time =
       gst_util_uint64_scale_int (src->next_sample, GST_SECOND, src->samplerate);
 
-  g_assert (src->next_time <= time);
+  g_assert (src->next_time <= time_to_seek);
 
   if (GST_CLOCK_TIME_IS_VALID (segment->stop)) {
-    time = segment->stop;
-    src->sample_stop = gst_util_uint64_scale_int (time, src->samplerate,
+    time_to_seek = segment->stop;
+    src->sample_stop = gst_util_uint64_scale_int (time_to_seek, src->samplerate,
         GST_SECOND);
     src->check_seek_stop = TRUE;
   } else {
@@ -1333,6 +1333,7 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec)
 {
   GstJammoSampler *src = GST_JAMMO_SAMPLER (object);
+  GstClockTime timestamp;
 
   switch (prop_id) {
     case PROP_SAMPLES_PER_BUFFER:
@@ -1455,14 +1456,14 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 			unsigned char note_ = event->note;
 
 			printf("remove event\n");
-			GstClockTime time= event->timestamp;
+			timestamp= event->timestamp;
 
 
 			JammoMidiEvent* candidate_for_removal=NULL;
 			GList* list;
 			JammoMidiEvent* n;
 
-			//printf("Removing this: %llu ms: note:%d \n",(unsigned long long)time,note_);
+			//printf("Removing this: %llu ms: note:%d \n",(unsigned long long)timestamp,note_);
 			for (list = src->eventlist; list; list = list->next) {
 				//printf(".\n");
 				n = (list->data);
@@ -1481,7 +1482,7 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 					continue;
 				}
 
-				if (time >= n->timestamp )
+				if (timestamp >= n->timestamp )
 					{
 						//printf("time is correct\n");
 						if (n->type==JAMMOMIDI_NOTE_ON)
@@ -1532,7 +1533,6 @@ gst_jammo_sampler_set_property (GObject * object, guint prop_id,
 			//realtime. There are no timestamp in event, use current time
 			if (src->recording){
 			//printf("realtime\n");
-			GstClockTime timestamp;
 			timestamp = src->time * src->tempo_scale;
 
 			event->timestamp=timestamp;
